==> haskell-gtk-strut-0.1.3.2-165-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-GVLA6DtaYSYHx5kjYkHLBR
key:                  gtk-strut-0.1.3.2-GVLA6DtaYSYHx5kjYkHLBR
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  cc49e5c48bd607076993995209ef3127
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-GVLA6DtaYSYHx5kjYkHLBR
depends:
    base-4.16.4.0 data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS
    gi-gdk-3.0.25-HPKsM8HP3aw65t8gSkjNIq
    gi-gtk-3.0.38-8niBydQ2etRHYeSa6lu9S5
    hslogger-1.3.1.1-AaFqNA3CZ3wF1V1MzkMbBe text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-strut-0.1.3.2-167-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-Jm6msFutHzh38L59TKKMfz
key:                  gtk-strut-0.1.3.2-Jm6msFutHzh38L59TKKMfz
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  d15093b73d195020e171514b1788df35
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-Jm6msFutHzh38L59TKKMfz
depends:
    base-4.16.4.0 data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS
    gi-gdk-3.0.25-674KCM9cqb319oJEUl23oN
    gi-gtk-3.0.38-5lmiLtDqsp72IxYF3k3O6c
    hslogger-1.3.1.1-AaFqNA3CZ3wF1V1MzkMbBe text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
